@@ -780,8 +780,13 @@ class Variable(AffineScalarFunc):
         to_string() is typically repr() or str().
         """
         num_repr  = super(Variable, self)._general_representation(to_string)
-        # Optional tag:
-        return (num_repr if self.tag is None
+        
+        # Optional tag: only full representations (to_string == repr)
+        # contain the tag, as the tag is required in order to recreate
+        # the variable.  Outputing the tag for regular string ("print
+        # x") would be too heavy and produce an unusual representation
+        # of a number with uncertainty.
+        return (num_repr if ((self.tag is None) or (to_string != repr))
                 else "< %s = %s >" % (self.tag, num_repr))
 
 ###############################################################################
